==> kubernetes-model-1.0.54-sources.jar: annotations/io/fabric8/kubernetes/api/model/PodStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.Valid;
import java.util.ArrayList;
import java.lang.String;
import java.lang.Object;
import io.fabric8.kubernetes.api.builder.Nested;

public class PodStatusFluentImpl<A extends PodStatusFluent<A>> extends BaseFluent<A> implements PodStatusFluent<A>{

    private List<VisitableBuilder<? extends ContainerStatus,?>> initContainerStatuses =  new ArrayList<VisitableBuilder<? extends ContainerStatus,?>>();
    private List<VisitableBuilder<? extends PodCondition,?>> conditions =  new ArrayList<VisitableBuilder<? extends PodCondition,?>>();
    private List<VisitableBuilder<? extends ContainerStatus,?>> containerStatuses =  new ArrayList<VisitableBuilder<? extends ContainerStatus,?>>();
    private String hostIP;
    private String message;
    private String phase;
    private String podIP;
    private String reason;
    private String startTime;

    public PodStatusFluentImpl(){
    }
    public PodStatusFluentImpl(PodStatus instance){
            this.withInitContainerStatuses(instance.getInitContainerStatuses()); 
            this.withConditions(instance.getConditions()); 
            this.withContainerStatuses(instance.getContainerStatuses()); 
            this.withHostIP(instance.getHostIP()); 
            this.withMessage(instance.getMessage()); 
            this.withPhase(instance.getPhase()); 
            this.withPodIP(instance.getPodIP()); 
            this.withReason(instance.getReason()); 
            this.withStartTime(instance.getStartTime()); 
    }

    public A addToInitContainerStatuses(ContainerStatus... items){
            for (ContainerStatus item : items) {ContainerStatusBuilder builder = new ContainerStatusBuilder(item);_visitables.add(builder);this.initContainerStatuses.add(builder);} return (A)this;
    }

    public A removeFromInitContainerStatuses(ContainerStatus... items){
            for (ContainerStatus item : items) {ContainerStatusBuilder builder = new ContainerStatusBuilder(item);_visitables.remove(builder);this.initContainerStatuses.remove(builder);} return (A)this;
    }

    public List<ContainerStatus> getInitContainerStatuses(){
            return build(initContainerStatuses);
    }

    public A withInitContainerStatuses(List<ContainerStatus> initContainerStatuses){
            this.initContainerStatuses.clear();
            if (initContainerStatuses != null) {for (ContainerStatus item : initContainerStatuses){this.addToInitContainerStatuses(item);}} return (A) this;
    }

    public A withInitContainerStatuses(ContainerStatus... initContainerStatuses){
            this.initContainerStatuses.clear(); if (initContainerStatuses != null) {for (ContainerStatus item :initContainerStatuses){ this.addToInitContainerStatuses(item);}} return (A) this;
    }

    public PodStatusFluent.InitContainerStatusesNested<A> addNewInitContainerStatus(){
            return new InitContainerStatusesNestedImpl();
    }

    public PodStatusFluent.InitContainerStatusesNested<A> addNewInitContainerStatusLike(ContainerStatus item){
            return new InitContainerStatusesNestedImpl(item);
    }

    public A addToConditions(PodCondition... items){
            for (PodCondition item : items) {PodConditionBuilder builder = new PodConditionBuilder(item);_visitables.add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(PodCondition... items){
            for (PodCondition item : items) {PodConditionBuilder builder = new PodConditionBuilder(item);_visitables.remove(builder);this.conditions.remove(builder);} return (A)this;
    }

    public List<PodCondition> getConditions(){
            return build(conditions);
    }

    public A withConditions(List<PodCondition> conditions){
            this.conditions.clear();
            if (conditions != null) {for (PodCondition item : conditions){this.addToConditions(item);}} return (A) this;
    }

    public A withConditions(PodCondition... conditions){
            this.conditions.clear(); if (conditions != null) {for (PodCondition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public PodStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public PodStatusFluent.ConditionsNested<A> addNewConditionLike(PodCondition item){
            return new ConditionsNestedImpl(item);
    }

    public A addToContainerStatuses(ContainerStatus... items){
            for (ContainerStatus item : items) {ContainerStatusBuilder builder = new ContainerStatusBuilder(item);_visitables.add(builder);this.containerStatuses.add(builder);} return (A)this;
    }

    public A removeFromContainerStatuses(ContainerStatus... items){
            for (ContainerStatus item : items) {ContainerStatusBuilder builder = new ContainerStatusBuilder(item);_visitables.remove(builder);this.containerStatuses.remove(builder);} return (A)this;
    }

    public List<ContainerStatus> getContainerStatuses(){
            return build(containerStatuses);
    }

    public A withContainerStatuses(List<ContainerStatus> containerStatuses){
            this.containerStatuses.clear();
            if (containerStatuses != null) {for (ContainerStatus item : containerStatuses){this.addToContainerStatuses(item);}} return (A) this;
    }

    public A withContainerStatuses(ContainerStatus... containerStatuses){
            this.containerStatuses.clear(); if (containerStatuses != null) {for (ContainerStatus item :containerStatuses){ this.addToContainerStatuses(item);}} return (A) this;
    }

    public PodStatusFluent.ContainerStatusesNested<A> addNewContainerStatus(){
            return new ContainerStatusesNestedImpl();
    }

    public PodStatusFluent.ContainerStatusesNested<A> addNewContainerStatusLike(ContainerStatus item){
            return new ContainerStatusesNestedImpl(item);
    }

    public String getHostIP(){
            return this.hostIP;
    }

    public A withHostIP(String hostIP){
            this.hostIP=hostIP; return (A) this;
    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public String getPhase(){
            return this.phase;
    }

    public A withPhase(String phase){
            this.phase=phase; return (A) this;
    }

    public String getPodIP(){
            return this.podIP;
    }

    public A withPodIP(String podIP){
            this.podIP=podIP; return (A) this;
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public String getStartTime(){
            return this.startTime;
    }

    public A withStartTime(String startTime){
            this.startTime=startTime; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodStatusFluentImpl that = (PodStatusFluentImpl) o;
            if (initContainerStatuses != null ? !initContainerStatuses.equals(that.initContainerStatuses) :that.initContainerStatuses != null) return false;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (containerStatuses != null ? !containerStatuses.equals(that.containerStatuses) :that.containerStatuses != null) return false;
            if (hostIP != null ? !hostIP.equals(that.hostIP) :that.hostIP != null) return false;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
            if (podIP != null ? !podIP.equals(that.podIP) :that.podIP != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
            return true;
    }


    public class InitContainerStatusesNestedImpl<N> extends ContainerStatusFluentImpl<PodStatusFluent.InitContainerStatusesNested<N>> implements PodStatusFluent.InitContainerStatusesNested<N>,Nested<N>{

            private final ContainerStatusBuilder builder;
    
            InitContainerStatusesNestedImpl(ContainerStatus item){
                    this.builder = new ContainerStatusBuilder(this, item);
            }
            InitContainerStatusesNestedImpl(){
                    this.builder = new ContainerStatusBuilder(this);
            }
    
    public N and(){
            return (N) PodStatusFluentImpl.this.addToInitContainerStatuses(builder.build());
    }
    public N endInitContainerStatus(){
            return and();
    }

}
    public class ConditionsNestedImpl<N> extends PodConditionFluentImpl<PodStatusFluent.ConditionsNested<N>> implements PodStatusFluent.ConditionsNested<N>,Nested<N>{

            private final PodConditionBuilder builder;
    
            ConditionsNestedImpl(){
                    this.builder = new PodConditionBuilder(this);
            }
            ConditionsNestedImpl(PodCondition item){
                    this.builder = new PodConditionBuilder(this, item);
            }
    
    public N endCondition(){
            return and();
    }
    public N and(){
            return (N) PodStatusFluentImpl.this.addToConditions(builder.build());
    }

}
    public class ContainerStatusesNestedImpl<N> extends ContainerStatusFluentImpl<PodStatusFluent.ContainerStatusesNested<N>> implements PodStatusFluent.ContainerStatusesNested<N>,Nested<N>{

            private final ContainerStatusBuilder builder;
    
            ContainerStatusesNestedImpl(ContainerStatus item){
                    this.builder = new ContainerStatusBuilder(this, item);
            }
            ContainerStatusesNestedImpl(){
                    this.builder = new ContainerStatusBuilder(this);
            }
    
    public N and(){
            return (N) PodStatusFluentImpl.this.addToContainerStatuses(builder.build());
    }
    public N endContainerStatus(){
            return and();
    }

}


}

==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/PodStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;

public class PodStatusFluentImpl<A extends PodStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PodStatusFluent<A>{

    private List<VisitableBuilder<? extends PodCondition,?>> conditions =  new ArrayList<VisitableBuilder<? extends PodCondition,?>>();
    private List<VisitableBuilder<? extends ContainerStatus,?>> containerStatuses =  new ArrayList<VisitableBuilder<? extends ContainerStatus,?>>();
    private String hostIP;
    private String message;
    private String phase;
    private String podIP;
    private String reason;
    private String startTime;

    public PodStatusFluentImpl(){
    }
    public PodStatusFluentImpl(PodStatus instance){
            this.withConditions(instance.getConditions()); 
            this.withContainerStatuses(instance.getContainerStatuses()); 
            this.withHostIP(instance.getHostIP()); 
            this.withMessage(instance.getMessage()); 
            this.withPhase(instance.getPhase()); 
            this.withPodIP(instance.getPodIP()); 
            this.withReason(instance.getReason()); 
            this.withStartTime(instance.getStartTime()); 
    }

    public A addToConditions(PodCondition... items){
            for (PodCondition item : items) {PodConditionBuilder builder = new PodConditionBuilder(item);_visitables.add(builder);this.conditions.add(builder);} return (A)this;
    }

    public A removeFromConditions(PodCondition... items){
            for (PodCondition item : items) {PodConditionBuilder builder = new PodConditionBuilder(item);_visitables.remove(builder);this.conditions.remove(builder);} return (A)this;
    }

    public List<PodCondition> getConditions(){
            return build(conditions);
    }

    public A withConditions(List<PodCondition> conditions){
            _visitables.removeAll(this.conditions);
            this.conditions.clear();
            if (conditions != null) {for (PodCondition item : conditions){this.addToConditions(item);}} return (A) this;
    }

    public A withConditions(PodCondition... conditions){
            this.conditions.clear(); if (conditions != null) {for (PodCondition item :conditions){ this.addToConditions(item);}} return (A) this;
    }

    public PodStatusFluent.ConditionsNested<A> addNewCondition(){
            return new ConditionsNestedImpl();
    }

    public PodStatusFluent.ConditionsNested<A> addNewConditionLike(PodCondition item){
            return new ConditionsNestedImpl(item);
    }

    public A addToContainerStatuses(ContainerStatus... items){
            for (ContainerStatus item : items) {ContainerStatusBuilder builder = new ContainerStatusBuilder(item);_visitables.add(builder);this.containerStatuses.add(builder);} return (A)this;
    }

    public A removeFromContainerStatuses(ContainerStatus... items){
            for (ContainerStatus item : items) {ContainerStatusBuilder builder = new ContainerStatusBuilder(item);_visitables.remove(builder);this.containerStatuses.remove(builder);} return (A)this;
    }

    public List<ContainerStatus> getContainerStatuses(){
            return build(containerStatuses);
    }

    public A withContainerStatuses(List<ContainerStatus> containerStatuses){
            _visitables.removeAll(this.containerStatuses);
            this.containerStatuses.clear();
            if (containerStatuses != null) {for (ContainerStatus item : containerStatuses){this.addToContainerStatuses(item);}} return (A) this;
    }

    public A withContainerStatuses(ContainerStatus... containerStatuses){
            this.containerStatuses.clear(); if (containerStatuses != null) {for (ContainerStatus item :containerStatuses){ this.addToContainerStatuses(item);}} return (A) this;
    }

    public PodStatusFluent.ContainerStatusesNested<A> addNewContainerStatus(){
            return new ContainerStatusesNestedImpl();
    }

    public PodStatusFluent.ContainerStatusesNested<A> addNewContainerStatusLike(ContainerStatus item){
            return new ContainerStatusesNestedImpl(item);
    }

    public String getHostIP(){
            return this.hostIP;
    }

    public A withHostIP(String hostIP){
            this.hostIP=hostIP; return (A) this;
    }

    public String getMessage(){
            return this.message;
    }

    public A withMessage(String message){
            this.message=message; return (A) this;
    }

    public String getPhase(){
            return this.phase;
    }

    public A withPhase(String phase){
            this.phase=phase; return (A) this;
    }

    public String getPodIP(){
            return this.podIP;
    }

    public A withPodIP(String podIP){
            this.podIP=podIP; return (A) this;
    }

    public String getReason(){
            return this.reason;
    }

    public A withReason(String reason){
            this.reason=reason; return (A) this;
    }

    public String getStartTime(){
            return this.startTime;
    }

    public A withStartTime(String startTime){
            this.startTime=startTime; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodStatusFluentImpl that = (PodStatusFluentImpl) o;
            if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
            if (containerStatuses != null ? !containerStatuses.equals(that.containerStatuses) :that.containerStatuses != null) return false;
            if (hostIP != null ? !hostIP.equals(that.hostIP) :that.hostIP != null) return false;
            if (message != null ? !message.equals(that.message) :that.message != null) return false;
            if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
            if (podIP != null ? !podIP.equals(that.podIP) :that.podIP != null) return false;
            if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
            if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
            return true;
    }


    public class ConditionsNestedImpl<N> extends PodConditionFluentImpl<PodStatusFluent.ConditionsNested<N>> implements PodStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final PodConditionBuilder builder;
    
            ConditionsNestedImpl(PodCondition item){
                    this.builder = new PodConditionBuilder(this, item);
            }
            ConditionsNestedImpl(){
                    this.builder = new PodConditionBuilder(this);
            }
    
    public N and(){
            return (N) PodStatusFluentImpl.this.addToConditions(builder.build());
    }
    public N endCondition(){
            return and();
    }

}
    public class ContainerStatusesNestedImpl<N> extends ContainerStatusFluentImpl<PodStatusFluent.ContainerStatusesNested<N>> implements PodStatusFluent.ContainerStatusesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ContainerStatusBuilder builder;
    
            ContainerStatusesNestedImpl(ContainerStatus item){
                    this.builder = new ContainerStatusBuilder(this, item);
            }
            ContainerStatusesNestedImpl(){
                    this.builder = new ContainerStatusBuilder(this);
            }
    
    public N and(){
            return (N) PodStatusFluentImpl.this.addToContainerStatuses(builder.build());
    }
    public N endContainerStatus(){
            return and();
    }

}


}
